@@ -210,6 +210,7 @@ ags_live_vst3_bridge_init(AgsLiveVst3Bridge *live_vst3_bridge)
   GtkLabel *label;
   GtkGrid *grid;
   GtkCellRenderer *cell_renderer;
+  GtkMenuItem *item;
 
   AgsAudio *audio;
 
@@ -353,6 +354,30 @@ ags_live_vst3_bridge_init(AgsLiveVst3Bridge *live_vst3_bridge)
 		  (GtkWidget *) AGS_EFFECT_BRIDGE(AGS_MACHINE(live_vst3_bridge)->bridge)->bulk_input,
 		  0, 0,
 		  1, 1);
+
+  /* vst3 */
+  live_vst3_bridge->icomponent = NULL;
+  live_vst3_bridge->iedit_controller = NULL;
+
+  live_vst3_bridge->icomponent_handler = NULL;
+  
+  live_vst3_bridge->iplug_view = NULL;
+  
+  /* vst3 menu */
+  item = (GtkMenuItem *) gtk_menu_item_new_with_label("VST3");
+  gtk_menu_shell_append((GtkMenuShell *) AGS_MACHINE(live_vst3_bridge)->popup,
+			(GtkWidget *) item);
+  gtk_widget_show((GtkWidget *) item);
+  
+  live_vst3_bridge->vst3_menu = (GtkMenu *) gtk_menu_new();
+  gtk_menu_item_set_submenu((GtkMenuItem *) item,
+			    (GtkWidget *) live_vst3_bridge->vst3_menu);
+
+  item = (GtkMenuItem *) gtk_menu_item_new_with_label(i18n("show GUI"));
+  gtk_menu_shell_append((GtkMenuShell *) live_vst3_bridge->vst3_menu,
+			(GtkWidget *) item);
+
+  gtk_widget_show_all((GtkWidget *) live_vst3_bridge->vst3_menu);
 }
 
 void
@@ -497,6 +522,8 @@ ags_live_vst3_bridge_connect(AgsConnectable *connectable)
 {
   AgsLiveVst3Bridge *live_vst3_bridge;
 
+  GList *list, *list_start;
+
   if((AGS_MACHINE_CONNECTED & (AGS_MACHINE(connectable)->flags)) != 0){
     return;
   }
@@ -507,6 +534,15 @@ ags_live_vst3_bridge_connect(AgsConnectable *connectable)
 
   g_signal_connect_after(G_OBJECT(live_vst3_bridge->program), "changed",
 			 G_CALLBACK(ags_live_vst3_bridge_program_changed_callback), live_vst3_bridge);
+
+  /* menu */
+  list =
+    list_start = gtk_container_get_children((GtkContainer *) live_vst3_bridge->vst3_menu);
+
+  g_signal_connect(G_OBJECT(list->data), "activate",
+		   G_CALLBACK(ags_live_vst3_bridge_show_gui_callback), live_vst3_bridge);
+
+  g_list_free(list_start);
 }
 
 void
@@ -876,14 +912,23 @@ ags_live_vst3_bridge_load(AgsLiveVst3Bridge *live_vst3_bridge)
 
   AgsVst3Plugin *vst3_plugin;
 
+  AgsConfig *config;
+  
   AgsVstIUnitInfo *iunit_info;    
 
   GList *start_program, *program;
+  
+  gchar **parameter_name;
 
+  guint buffer_size;
+  guint samplerate;
+  guint n_params;
   guint i, i_stop;
   guint j, j_stop;
   AgsVstTResult val;
   
+  GValue *value;
+  
   /* load plugin */
   vst3_plugin = ags_vst3_manager_find_vst3_plugin(ags_vst3_manager_get_instance(),
 						  live_vst3_bridge->filename,
@@ -893,7 +938,79 @@ ags_live_vst3_bridge_load(AgsLiveVst3Bridge *live_vst3_bridge)
      vst3_plugin->iedit_controller == NULL){
     return;
   }
+  
+  /* ui */
+  config = ags_config_get_instance();
+  
+#if HAVE_GLIB_2_68
+  strv_builder = g_strv_builder_new();
 
+  g_strv_builder_add(strv_builder,
+		     "buffer-size");
+  g_strv_builder_add(strv_builder,
+		     "samplerate");
+  g_strv_builder_add(strv_builder,
+		     "iedit-controller");
+  g_strv_builder_add(strv_builder,
+		     "iaudio-processor");
+  g_strv_builder_add(strv_builder,
+		     "iedit-controller-host-editing");
+  
+  parameter_name = g_strv_builder_end(strv_builder);
+#else
+  parameter_name = (gchar **) g_malloc(6 * sizeof(gchar *));
+
+  parameter_name[0] = g_strdup("buffer-size");
+  parameter_name[1] = g_strdup("samplerate");
+  parameter_name[2] = g_strdup("iedit-controller");
+  parameter_name[3] = g_strdup("iaudio-processor");
+  parameter_name[4] = g_strdup("iedit-controller-host-editing");
+  parameter_name[5] = NULL;
+#endif
+
+  n_params = 5;
+
+  value = g_new0(GValue,
+		 5);
+
+  g_value_init(value,
+	       G_TYPE_UINT);
+    
+  g_value_init(value + 1,
+	       G_TYPE_UINT);
+    
+  g_value_init(value + 2,
+	       G_TYPE_POINTER);
+
+  g_value_init(value + 3,
+	       G_TYPE_POINTER);
+
+  g_value_init(value + 4,
+	       G_TYPE_POINTER);
+
+  samplerate = ags_soundcard_helper_config_get_samplerate(config);
+  buffer_size = ags_soundcard_helper_config_get_buffer_size(config);
+
+  g_value_set_uint(value,
+		   buffer_size);
+
+  g_value_set_uint(value + 1,
+		   samplerate);
+
+  live_vst3_bridge->icomponent = ags_base_plugin_instantiate_with_params((AgsBasePlugin *) vst3_plugin,
+									 &n_params,
+									 &parameter_name, &value);
+  
+  live_vst3_bridge->iedit_controller = g_value_get_pointer(value + 2);
+  
+  live_vst3_bridge->icomponent_handler = ags_vst_component_handler_new();
+	    
+  ags_vst_iedit_controller_set_component_handler(live_vst3_bridge->iedit_controller,
+						 live_vst3_bridge->icomponent_handler);
+  
+  g_strfreev(parameter_name);
+  g_free(value);
+  
   /*  */
   gtk_list_store_clear(GTK_LIST_STORE(gtk_combo_box_get_model(GTK_COMBO_BOX(live_vst3_bridge->program))));
 
